@@ -1,5 +1,21 @@
+function _aws_cdk_assertions_MatchCapture(p) {
+    if (p == null)
+        return;
+    visitedObjects.add(p);
+    if (!visitedObjects.has(p.capture))
+        _aws_cdk_assertions_Capture(p.capture);
+    visitedObjects.delete(p);
+}
 function _aws_cdk_assertions_Matcher(p) {
 }
+function _aws_cdk_assertions_MatchFailure(p) {
+    if (p == null)
+        return;
+    visitedObjects.add(p);
+    if (!visitedObjects.has(p.matcher))
+        _aws_cdk_assertions_Matcher(p.matcher);
+    visitedObjects.delete(p);
+}
 function _aws_cdk_assertions_Capture(p) {
 }
 function _aws_cdk_assertions_Template(p) {
@@ -23,5 +39,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_assertions_Matcher, _aws_cdk_assertions_Capture, _aws_cdk_assertions_Template, _aws_cdk_assertions_MatchResult, _aws_cdk_assertions_Match };
+module.exports = { print, _aws_cdk_assertions_MatchCapture, _aws_cdk_assertions_Matcher, _aws_cdk_assertions_MatchFailure, _aws_cdk_assertions_Capture, _aws_cdk_assertions_Template, _aws_cdk_assertions_MatchResult, _aws_cdk_assertions_Match };
 module.exports.DeprecationError = DeprecationError;
